# -*- coding: utf-8 -*-


class Currency(object):
    """
    Трехбуквенный код валюты в формате [ISO-4217](https://www.iso.org/iso-4217-currency-codes.html).
    """  # noqa: E501

    """
    Список допустимых значений
    """
    RUB = "RUB"
    """Российский рубль"""
    USD = "USD"
    """Доллар США"""
    EUR = "EUR"
    """Евро"""
    BYN = "BYN"
    """Белорусский рубль"""
    CNY = "CNY"
    """Китайская йена"""
    KZT = "KZT"
    """Казахский тенге"""
    UAH = "UAH"
    """Украинская гривна"""
    UZS = "UZS"
    """Узбекский сум"""
    TRY = "TRY"
    """Турецкая лира"""
    INR = "INR"
    """Индийская рупия"""
    MDL = "MDL"
    """Молдавский лей"""
    AZN = "AZN"
    """Азербайджанский манат"""
    AMD = "AMD"
    """Армянский драм"""
